@@ -3,14 +3,13 @@ use 5.012;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.13";
+our $VERSION = "0.14";
 use Moo;
 use HTTP::Tiny '0.056';
 use JSON::Tiny qw[decode_json];
 use Try::Tiny;
 use strictures 2;
 use namespace::clean;
-use DateTime;
 our $DEBUG = !1;
 require Data::Dump if $DEBUG;
 our $DEV = !1;
@@ -71,7 +70,7 @@ my %endpoints = (
 
 sub endpoint {
     $endpoints{$_[0]} ?
-        ($DEV ?
+        ($DEV > 10 ?
              'http://brokeback.dev.robinhood.com/'
          : 'https://api.robinhood.com/'
         )
@@ -87,8 +86,8 @@ my %headers = (
          'Accept-Language' =>
              'en;q=1, fr;q=0.9, de;q=0.8, ja;q=0.7, nl;q=0.6, it;q=0.5',
          'Content-Type' => 'application/x-www-form-urlencoded; charset=utf-8',
-         'X-Robinhood-API-Version' => '1.70.0',
-         'User-Agent' => 'Robinhood/823 (iPhone; iOS 7.1.2; Scale/2.00)'
+         'X-Robinhood-API-Version' => '1.120.0',
+         'User-Agent'              => 'Robinhood/2357 (Android/2.19.0)'
 );
 sub errors { shift; carp shift; }
 
@@ -603,9 +602,18 @@ sub _send_request {
     return wantarray ? ($res->{status}, $rt, $res) : $rt;
 }
 
-# Coerce ISO 8601-ish strings into DateTime objects
+# Coerce ISO 8601-ish strings into Time::Piece or DateTime objects
 sub _2_datetime {
     return if !$_[0];
+    if ($DEV && !defined $Time::Piece::VERSION)
+    {    # We lose millisecond timestamps but gain speed!
+        require Time::Piece;
+    }
+    if ($Time::Piece::VERSION) {
+        $_[0] =~ s[\..*][];
+        return Time::Piece->strptime($_[0], '%Y-%m-%dT%H:%M:%S');
+    }
+    require DateTime;
     $_[0]
         =~ m[(\d{4})-(\d\d)-(\d\d)(?:T(\d\d):(\d\d):(\d\d)(?:\.(\d+))?(.+))?];
     DateTime->new(year  => $1,
@@ -977,8 +985,8 @@ This method returns a list of hashes which in turn contain the following keys:
 
 =over
 
-=item C<begins_at> - A DateTime object indicating the timestamp of this block
-of data.
+=item C<begins_at> - A Time::Piece or DateTime object indicating the timestamp
+of this block of data.
 
 =item C<close_price> - The most recent close price during this interval.
 
